@@ -10,6 +10,9 @@ class TargetApp(BaseModel):
     def to_slashed_string(self):
         return f"{self.app}/{self.version}/{self.branch}"
 
+    def to_provider_string(self):
+        return f"{self.app}/{self.version}"
+
     @staticmethod
     def from_unique_slashed_string(slashed_string: str):
         target = slashed_string.split("/")
